Changelog
=========

* :release:`0.14.0 <19-10-2017>`
* :feature:`43` Add option to pass arbitrary arguments to celery start-worker
* :feature:`40` Added ability to make background tasks run in app context
* :feature:`44` Allow specifying cob version to use via `COB_VERSION` environment variable
* :feature:`42` Cob now supports specifying the pypi index URL to use via `COB_INDEX_URL`
* :release:`0.0.1 <16-11-2016>`
* :feature:`-` First operational release
